Package: survcomp
Type: Package
Title: Performance Assessment and Comparison for Survival Analysis
Version: 1.61.1
Date: 2021-12-14
Description: Assessment and Comparison for Performance of Risk
        Prediction (Survival) Models.
biocViews: GeneExpression, DifferentialExpression, Visualization
Authors@R: c(
    person("Benjamin", "Haibe-Kains", email="benjamin.haibe.kains@utoronto.ca",
        role=c("aut", "cre")), 
    person("Markus" , "Schroeder", email="markus.schroeder@ucdconnect.ie",
        role=c("aut")), 
    person("Catharina", "Olsen", email="colsen@ulb.ac.be", 
        role=c("aut")),
    person("Christos", "Sotiriou", role=c("aut")),
    person("Gianluca", "Bontempi", role=c("aut")),
    person("John", "Quackenbush", role=c("aut")),
    person("Samuel", "Branders", role=c("aut")),
    person("Zhaleh", "Safikhani", role=c("aut"))
    )
Depends: survival, prodlim, R (>= 3.4)
Suggests: Hmisc, clinfun, xtable, Biobase, BiocManager
Imports: ipred, SuppDists, KernSmooth, survivalROC, bootstrap, grid,
        rmeta, stats, graphics
License: Artistic-2.0
URL: http://www.pmgenomics.ca/bhklab/
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-03-06 14:40:31 UTC
RemoteUrl: https://github.com/bioc/survcomp
RemoteRef: HEAD
RemoteSha: e7ba2a55b999989eeed91295922d4d1b1ab2f523
NeedsCompilation: yes
Packaged: 2026-03-07 04:05:10 UTC; root
Author: Benjamin Haibe-Kains [aut, cre],
  Markus Schroeder [aut],
  Catharina Olsen [aut],
  Christos Sotiriou [aut],
  Gianluca Bontempi [aut],
  John Quackenbush [aut],
  Samuel Branders [aut],
  Zhaleh Safikhani [aut]
Maintainer: Benjamin Haibe-Kains <benjamin.haibe.kains@utoronto.ca>
Built: R 4.6.0; aarch64-apple-darwin23; 2026-03-07 04:36:01 UTC; unix
