\name{mrmr_cIndex}
\alias{mrmr_cIndex}
\title{
mRMR cIndex
}
\description{
mRMR cIndex
}
\arguments{
\item{Rdata}{...}
\item{Rnamat}{...}
\item{RcIndex}{...}
\item{Rnvar}{...}
\item{Rnsample}{...}
\item{Rthreshold}{...}
}
\author{
Catharina Colsen
}
\keyword{ methods }
